@@ -1,8 +1,22 @@
 import os
 import subprocess
 import argparse
+import re
 from datetime import datetime
 
+def get_jira_ticket_number(commit_message):
+  # Use a regular expression to search for a JIRA ticket number
+  # in the commit message. The ticket number is typically
+  # formatted as "PROJECT-123" where PROJECT is the JIRA project
+  # key and 123 is the ticket number.
+  match = re.search(r'\b[A-Z]+-\d+\b', commit_message)
+  if match:
+    # Return the ticket number if it was found
+    return match.group()
+  else:
+    # Return None if no ticket number was found
+    return None
+
 def main():
 
   # Get the current working directory
@@ -11,6 +25,8 @@ def main():
   # Set up the command-line arguments parser
   parser = argparse.ArgumentParser()
   parser.add_argument("days", type=int, help="Number of days to filter the commit messages by")
+  parser.add_argument('--jira', action='store_true', help="Use to parse and collect only the jira ticket number from the commit messages")
+  parser.add_argument('--verbose', action='store_true', help="Use to make the collector more talky")
   args = parser.parse_args()
 
   # Get the number of days from the command-line argument
@@ -33,7 +49,8 @@ def main():
   for repo in repo_list:
     # Change the current working directory to the repository
     os.chdir(os.path.join(repo_directory, repo))
-    print(repo)
+    if args.verbose:
+      print(repo)
     # Run the `git log` command to get the commit messages, filtering only commits that you created and are within the specified time range
     output = subprocess.run(["git", "config", "--get", "user.name"], capture_output=True)
 
@@ -47,6 +64,8 @@ def main():
     for commithash in hashes:
       if commithash:
         commit_message = subprocess.run(["git", "log", "--format=%s", "-1", commithash], capture_output=True).stdout.decode("utf-8").strip()
+        if args.jira:
+          commit_message = get_jira_ticket_number(commit_message)
         date = subprocess.run(["git", "log", "--format=%cd", "-1", "--date=short", commithash], capture_output=True).stdout.decode("utf-8").strip()
         if date not in messages_by_date:
           messages_by_date[date] = {}
@@ -59,9 +78,9 @@ def main():
 
   with open("output/commit_messages.txt", "w") as f:
     for date, rest in sorted(messages_by_date.items(), key = lambda x:datetime.strptime(x[0], '%Y-%m-%d'), reverse=True):
-      f.write(f"{date}\n")
+      f.write(f"📅 {date}\n")
       for service, messages in rest.items():
-        f.write(f"    {service}\n")
+        f.write(f"    📂 {service}\n")
         for message in messages:
           f.write(f"        {message}\n")
 
